==> k4de-0.3.0.tgz: k4de-0.3.0/src/kde/texture/colorwidget.h <==
/******************************************************************************
**                                                                           **
**    k4de - 3d-editor for the K Desktop Enviroment                          **
**                                                                           **
**    Copyright (C) 1999  Tobias Wollgam (tobias.wollgam@gmx.de)             **
**    Copyright (C) 1999  Markus Weber (mweber@gmx.de)                       **
**                                                                           **
**    This program is free software; you can redistribute it and/or modify   **
**    it under the terms of the GNU General Public License as published by   **
**    the Free Software Foundation; either version 2 of the License, or      **
**    (at your option) any later version.                                    **
**                                                                           **
**    This program is distributed in the hope that it will be useful,        **
**    but WITHOUT ANY WARRANTY; without even the implied warranty of         **
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          **
**    GNU General Public License for more details.                           **
**                                                                           **
**    You should have received a copy of the GNU General Public License      **
**    along with this program; if not, write to the Free Software            **
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              **
**                                                                           **
******************************************************************************/
/*
** colorwidget.h
*/
#ifndef __COLORWIDGET_H__
#define __COLORWIDGET_H__


#include <qwidget.h>
#include <qgroupbox.h>
#include <qpainter.h>
#include <qcolor.h>
#include <kcolorbtn.h>
#include <qdialog.h>
#include <qlineedit.h>
#include <qcheckbox.h>

#include <color.h>
#include <qcolor.h>
#include "../misc/spinbox.h"
#include "../widgets/percentwidget.h"


class ColorWidget : public QWidget
{
Q_OBJECT
protected:
	color *co;
	QColor qc;
	KColorButton		*colorbt;
	QLineEdit		*name;
	PercentWidget		*transp,*filter;
	QPushButton		*okay,*cancel;
	QLabel			*nameLabel,*transpLabel;
	QCheckBox		*active;

public:

	ColorWidget(QWidget *p, color *);
	~ColorWidget();
	color *getColor();

	int 	width();
	int	height();

	void	paintEvent(QPaintEvent*);

};
//----------------------------------------------------


class ColorDialog : public QDialog
{
Q_OBJECT
protected:

	QPushButton		*ok,*cancel;
	ColorWidget		*pw;

public:

	ColorDialog(QWidget *p, color *);
	~ColorDialog();

protected:
	void	paintEvent(QPaintEvent*);
public slots:
	void okayPressed();
	void cancelPressed();
};


#endif

==> k4de-0.4.0.tgz: k4de-0.4.0/src/kde/texture/colorwidget.h <==
/******************************************************************************
**                                                                           **
**    k4de - 3d-editor for the K Desktop Enviroment                          **
**                                                                           **
**    Copyright (C) 1999  Tobias Wollgam (tobias.wollgam@gmx.de)             **
**    Copyright (C) 1999  Markus Weber (mweber@gmx.de)                       **
**                                                                           **
**    This program is free software; you can redistribute it and/or modify   **
**    it under the terms of the GNU General Public License as published by   **
**    the Free Software Foundation; either version 2 of the License, or      **
**    (at your option) any later version.                                    **
**                                                                           **
**    This program is distributed in the hope that it will be useful,        **
**    but WITHOUT ANY WARRANTY; without even the implied warranty of         **
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          **
**    GNU General Public License for more details.                           **
**                                                                           **
**    You should have received a copy of the GNU General Public License      **
**    along with this program; if not, write to the Free Software            **
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              **
**                                                                           **
******************************************************************************/
/*
** colorwidget.h
*/
#ifndef __COLORWIDGET_H__
#define __COLORWIDGET_H__


#include <qwidget.h>
#include <qgroupbox.h>
#include <qpainter.h>
#include <qcolor.h>
#include <kcolorbtn.h>
#include <qdialog.h>

#include "texturewidgetbase.h"

#include <color.h>
#include <qcolor.h>
#include "../widgets/spinbox.h"
#include "../widgets/percentwidget.h"
#include "texturebasewidget.h"

class ColorWidget : public TextureWidgetBase
{
Q_OBJECT
protected:
	color *co;
	QColor qc;
	KColorButton		*colorbt;
	PercentWidget		*transp,*filter;
	QSize			qs;
	TextureBaseWidget	*tbasew;

public:

	ColorWidget(QWidget *p, color *);
	~ColorWidget();
	void 	getValue();

	virtual QSize	sizeHint() const;

	void	paintEvent(QPaintEvent*);
signals:
	void 	sizeChanged();
};
//----------------------------------------------------


class ColorDialog : public QDialog
{
Q_OBJECT
protected:

	QPushButton		*ok,*cancel;
	ColorWidget		*pw;

public:

	ColorDialog(QWidget *p, color *);
	~ColorDialog();

protected:
	void	paintEvent(QPaintEvent*);
public slots:
	void 	okayPressed();
	void 	cancelPressed();

};


#endif
